# dummy python release project

This is a *dummy* project that exists to test changes to the release process for Python projects at eLife.

It *should* illustrate how to incorporate a Python project into the Jenkins release process.

It is *not* a template for Python projects at eLife. Projects come in all shapes and sizes.
